D:\jq\jqplot\build\plugins\jqplot.pyramidRenderer.js

jqplot.pyramidRenderer.js
Summary

jqplot.pyramidRenderer.js |
Properties |
barPadding |
fill | True to fill the bars.
highlightMouseOver | True to highlight slice when moused over.
highlightMouseDown | True to highlight when a mouse button is pressed over a slice.
highlightColors | an array of colors to use when highlighting a slice.
synchronizeHighlight | Index of another series to highlight when this series is highlighted.
offsetBars | False will center bars on their y value.

### Properties

### barPadding

> this.barPadding = 10

### fill

> this.fill = true

True to fill the bars.

### highlightMouseOver

> this.highlightMouseOver = true

True to highlight slice when moused over. This must be false to enable highlightMouseDown to highlight when clicking on a slice.

### highlightMouseDown

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice. This will be disabled if highlightMouseOver is true.

### highlightColors

> this.highlightColors = []

an array of colors to use when highlighting a slice.

### synchronizeHighlight

> this.synchronizeHighlight = false

Index of another series to highlight when this series is highlighted. null or false to not synchronize.

### offsetBars

> this.offsetBars = false

False will center bars on their y value. True will push bars up by 1/2 bar width to fill between their y values. If true, there needs to be 1 more tick than there are bars.

> this.barPadding = 10

> this.fill = true

True to fill the bars.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.synchronizeHighlight = false

Index of another series to highlight when this series is highlighted.

> this.offsetBars = false

False will center bars on their y value.
Close